\NeedsTeXFormat{LaTeX2e}[1994/06/01]
\ProvidesClass{paper}%[2011/03/10 v.1.0 Class für Examensarbeiten, Ingo Reich]

%%%% thesis options %%%%%%%

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}

\newcommand{\@sizeoption@err}{\ClassError{thesis}
  {Cannot use size option \CurrentOption} 
  {The thesis class requires (and automatically loads) 12pt text}}

\DeclareOption{12pt}{\@sizeoption@err}
\DeclareOption{10pt}{\@sizeoption@err}

\newcommand{\@psizeoption@err}{\ClassError{thesis}
  {Cannot use paper size option \CurrentOption} 
  {The thesis class requires (and automatically loads) A4 paper}}

\DeclareOption{a5paper}{\@psizeoption@err}
\DeclareOption{b5paper}{\@psizeoption@err}
\DeclareOption{letterpaper}{\@psizeoption@err}
\DeclareOption{legalpaper}{\@psizeoption@err}
\DeclareOption{executivepaper}{\@psizeoption@err}
\DeclareOption{landscape}{\@psizeoption@err}

\ProcessOptions\relax
\LoadClass[12pt,a4paper]{article}

%%%%%%%%%%% encoding, page layout %%%%%%%%%%%%%%%%

\RequirePackage[utf8]{inputenc}
\RequirePackage[a4paper,lmargin=3.5cm,rmargin=3.0cm,
				tmargin=3.25cm,bmargin=3.25cm]{geometry} %showframe
		
\RequirePackage{fancyhdr}
	 \pagestyle{fancy}
	 \renewcommand{\sectionmark}[1]{% 
	 \markboth{\chaptername~\thesection:~#1}{}}
	 \fancyhead[RO,LE]{\thepage}
	 \fancyhead[CO,CE]{}
	 \fancyhead[LO,RE]{\textit{\nouppercase{\leftmark}}}
	 \fancyfoot[RO,RE]{}
	 \fancyfoot[LO,LE]{}
	 \fancyfoot[CO,CE]{}
	 \renewcommand{\headrulewidth}{0pt}
	%\fancypagestyle{plain}{% 
	%\fancyhf{}} % clear all header and footer fields 

% Please do not change line spreading:
\linespread{1.4}

%%%%%%%% headings %%%%%%%%%%%%%%%

\usepackage{titlesec}
\titleclass{\section}{top}
\assignpagestyle{\section}{plain}
	\titleformat{\section}
	 {\bfseries\large}
	 {\thesection.}
	{1em}
	{\bfseries}
	\titlespacing*{\section}{0pt}{2\baselineskip}{1\baselineskip}
	%
	 \titleformat{\subsection}
	 {\bfseries}
	 {\thesubsection}
	{.7em}
	{\bfseries}
	\titlespacing*{\subsection}{0pt}{1\baselineskip}{.5\baselineskip}
	%
	 \titleformat{\subsubsection}
	 {\bfseries}
	 {\thesubsubsection}
	{.7em}
	{\bfseries}
	\titlespacing*{\subsubsection}{0pt}{.5\baselineskip}{2pt}
	%
	\titleformat{\paragraph}[runin]
	{\normalfont\itshape}
	{}
	{7.5mm}
	{}
	\titlespacing*{\paragraph}{0pt}{0pt}{7.5mm}


%%%%%%%% footnotes (to match doc-style footnotes) %%%%%%%%%%%%%%
	 
\renewcommand\@makefntext[1]{%
    \noindent
    {\@makefnmark}~#1} 

%%%%%%%%% font issues: text & math %%%%%%%%%%%%
				
\RequirePackage[english,ngerman]{babel}
\RequirePackage[T1]{fontenc}
\RequirePackage{textcomp}
\usepackage[scaled=0.86]{berasans}
\usepackage[scaled=0.86]{beramono}
\RequirePackage[sc]{mathpazo}
\RequirePackage{amssymb}
\RequirePackage{amsmath}
\usepackage{amstext}
\usepackage{tipa}
\renewcommand\textipa[1]{% CM Typewriter IPA
	{\fontfamily{cmtt}\fontsize{12}{12}\fontencoding{T3}\selectfont #1}}


%%%%%%%% required packages %%%%%%%%%
	
\RequirePackage{xcolor}
\RequirePackage{graphicx}
\RequirePackage{enumitem}
	\setlist{itemsep=0pt,parsep=0pt,topsep=6pt}
\RequirePackage[longnamesfirst]{natbib}
	\bibpunct[:~]{(}{)}{;}{a}{}{,}
	\setlength{\bibsep}{0pt}
	\setlength{\bibhang}{1cm}

%%%%%%%%% linguistics %%%%%%%%%%%%%%%%%

\IfFileExists{stmaryrd.sty}%
   {\RequirePackage{stmaryrd}}%
   {\newcommand{\llbracket}{\ensuremath{\left [\!\left [}}%
     \newcommand{\rrbracket}{\ensuremath{\right ]\!\right ]}}}
\IfFileExists{cgloss4e.sty}%
	{\RequirePackage{cgloss4e} \nosinglegloss}
	{\newcommand{\gll}{}\newcommand{\glll}{}\newcommand{\trans}{}}
\IfFileExists{linguex.sty}%
	{\RequirePackage{linguex}
	\setlength{\Exindent}{0pt}
	\setlength{\Exlabelwidth}{0pt}
	\setlength{\Exlabelsep}{12mm}
	\setlength{\SubExleftmargin}{9mm}
	\def\refdash{}
	\def\firstrefdash{}
	\setlength{\Extopsep}{6pt}
	\let\eachwordone=\it
	\let\eachwordtwo=\rm
	\let\eachwordthree=\it}
	{\newcommand{\ex.}{}\newcommand{\exg.}{}%
	 \newcommand{\a.}{}\newcommand{\b.}{}\newcommand{\c.}{}}
\IfFileExists{cgloss.sty}%
	{\RequirePackage{cgloss}}{}
\IfFileExists{qtree.sty}%
	{\RequirePackage[nocenter]{qtree}%
	\linethickness{.7pt}}{}
	
%%%%%%%%%%%%%%%%% title & authors %%%%%%%%%%%%%%%%%%%%%%%

\renewcommand*{\title}[2][]{\gdef\@shorttitle{#1}\gdef\@title{#2}}
\renewcommand*{\author}[2][]{\gdef\@shortauthor{#1}\gdef\@author{#2}}
\newcommand*{\birthday}[1]{\gdef\@date{#1}\gdef\@birthday{#1}}
\renewcommand*{\date}[1]{\gdef\@date{#1}\gdef\datum{#1}}
\newcommand*{\strasse}[1]{\gdef\@strasse{#1}}
\newcommand*{\plz}[1]{\gdef\@plz{#1}}
\newcommand*{\ort}[1]{\gdef\@ort{#1}}
\newcommand*{\matrikel}[1]{\gdef\@matrikel{#1}}
\newcommand*{\email}[1]{\gdef\@email{#1}}
\newcommand*{\seminarleiter}[1]{\gdef\@seminarleiter{#1}}
\newcommand*{\seminar}[1]{\gdef\@seminar{#1}}
\newcommand*{\semester}[1]{\gdef\@semester{#1}}
\newcommand*{\artderarbeit}[1]{\gdef\@artderarbeit{#1}}

\def\maketitle{%
  \newpage
  \thispagestyle{empty}
  \null
  \vskip 1em%  
  \begin{center}%
    Universität des Saarlandes\\
    Philosophische Fakultät\\
    Germanistik\par
  \vskip 4em%  
    {\Large\bf \@title \par}%
    \vskip 2em%
    {\large \@artderarbeit}
    \vfill%
      \begin{tabular}[t]{c}%
        \textbf{\@author}\\
        \@strasse\\
        \@plz~\@ort\\
        \@matrikel\\
        \@email
      \end{tabular}\par%
    \vfill%
         \textbf{\@seminarleiter}\\
        \@seminar\\
        \@semester\\
    \vfill%
   \includegraphics[height=1.5cm]{logo}\par
  \vskip 1em%     
   Saarbrücken, den {\@date}
  \vskip 1em%  
  \end{center}%
  }


%%%%%%%%%%%% Varia %%%%%%%%%%%%%	

\renewenvironment{quote}
               {\list{}{\setlength{\rightmargin}{1cm}%
               			\setlength{\leftmargin}{1cm}}%
                \fontsize{10}{12}\selectfont%
                \item\relax}
               {\endlist}

\setlength{\parskip}{0pt}
\setlength{\parindent}{2em}
\newcommand{\clearemptydoublepage}{\newpage{\pagestyle{empty}\cleardoublepage}}

\newcommand{\erklaerung}{%
\clearemptydoublepage
\thispagestyle{empty}
\mbox{}\vspace*{2\baselineskip}
\begin{center}
\textbf{\large Selbständigkeitserklärung}
\end{center}\vspace*{.5\baselineskip}
%\begin{quote}
\normalsize Mit meiner Unterschrift bestätige ich, dass mir die für diese Prüfung relevanten Zulassungsvoraussetzungen aus der Anlage der für mich geltenden Prüfungsordnung bekannt sind. Mir ist damit bewusst, dass diese Prüfungsleistung als nicht abgelegt zählt, wenn die hierfür vorgesehenen Zulassungsvoraussetzungen nicht erfüllt sind. Mir ist bekannt, dass die Teilnahme an der Prüfung zudem die ordnungsgemäße Anmeldung zur Prüfung voraussetzt. Die Teilnahme an der Prüfung bei versäumter Anmeldung hat die Ungültigkeit der Prüfung zur Folge. Zudem ist mir bekannt, dass eine nicht bestandene Teilprüfung zweimal wiederholt werden kann. Die Wiederholung einer bestandenen Teilprüfung ist nicht zulässig. Ich erkläre zudem, dass ich die vorliegende Arbeit selbstständig und ohne die Beteiligung dritter Personen verfasst habe. Hiermit versichere ich, dass ich bei der Erstellung der Prüfung keine Hilfsmittel, insbesondere keine KI-basierte Software eingesetzt habe, deren Nutzung durch die Prüfenden nicht erlaubt wurde. Ich erkläre mich damit einverstanden, dass die Arbeit mittels eines Plagiatsprogrammes auf Plagiat und auf die Nutzung einer KI-basierten Software überprüft wird. Mir ist bewusst, dass der Verstoß gegen diese Versicherung zum Nichtbestehen der Prüfung bis hin zum Verlust des Prüfungsanspruchs führen kann. Außerdem erkläre ich, dass ich die Leistung auch nicht bereits für ein anderes Modul eingereicht habe. 
\vspace*{1\baselineskip}\par
\noindent Saarbrücken, den {\datum},
\vspace*{2\baselineskip}\par
\noindent Unterschrift:~~~~~~\hrulefill
%\end{quote}
}

